
### Actors ###

This implementation guide defines the following actors. Note, it is possible for a given system to play the role of multiple actors. For example, and EHR could be both the Data Source and dQM Evaluation Engine when calculating a measure internally. Likewise a system residing at NHSN that queries the Data Source remotely, evaluates those data, produces MeasureReport bundles, and validates the result may be both the dQM Evaluation Engine and MeasureReport Recipient. 

* **dQM Evaluation Engine** A system that retrieves data from the Data Source and evaluates those data against one or more measures retrieved from the Measure Source. The resulting MeasureReport bundle and related resources are then sent to the MeasureReport recipient The dQM Evaluation Engine acts as a [US Core Client]({{site.data.fhir.ver.uscore}}/CapabilityStatement-us-core-client.html), a [DEQM Reporter Client]({{site.data.fhir.ver.deqm}}/CapabilityStatement-reporter-client.html), and implements the $evaluation-measure operation

* **Data Source** A system containing data (typically patient data, but could be situational awareness data) that will be evaluated against one or more measures. This may be a FHIR server, an EHR with a FHIR endpoint (facade), an internal data store when the Data Source and dQM Evaluation Engine actors are played by the same system such as an EHR that does it's own measure evaluation, or it may be a system containing other data such as situational awareness data that is reporting via CSV or other format. When FHIR enabled, the Data Source acts as a [US Core Server]({{site.data.fhir.ver.uscore}}/CapabilityStatement-us-core-server.html)

* **Data Aggregator** For some example use cases, such as bed capacity reporting, data from multiple Data Source actors may be aggregated by a single system before measure evaluation. A Data Aggregator also plays the role of a Data Source once aggregation is complete. An example would be a state public health agency aggregating data from all facilities in the state before using those data to produce a MeasureReport containing bed capacity data for the entire state. When FHIR enabled, a Data Aggregator acts as a [US Core Server]({{site.data.fhir.ver.uscore}}/CapabilityStatement-us-core-server.html) when playing the role of a Data Source after aggregation. During aggregation, the Data Aggregator acts similar to the SANER options for aggregation, but implements its own CapabilityStatement due to the incompatibilities between DEQM and SANER.

* **Measure Source** A system at NHSN that stores FHIR resources such as Measure, Library, ValueSet, etc. that are used for dQM Reporting. The dQM Evaluation Engine queries the Measure Source for the latest Measure content before querying the Patient Data Source and performing measure evaluation. The Measure Source acts as a [CQFM Publishable Measure Repository]({{site.data.fhir.ver.cqfm}}/measure-repository-service.html#publishable-measure-repository) 

* **MeasureReport Recipient** A system at NHSN that receives MeasureReport bundles from the dQM Evaluation Engine and validates the result against the profiles in this implementation guide, and potentially other measure-specific profiles that are distributed with the measures themselves (this kind of validation is referred to as "pre-qualification" at NHSN). The MeasureReport Recipient acts as a [DEQM Receiver Server]({{site.data.fhir.ver.deqm}}/CapabilityStatement-receiver-server.html), provides write access to Bundle resources containing MeasureReport and other related resources, and implements the $validate operation.